@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
@@ -9,7 +9,8 @@
 #define QTRESOURCETEMPLATELOADER_H
 #include "grantlee/templateloader.h"
 
-namespace KCalUtils {
+namespace KCalUtils
+{
 class QtResourceTemplateLoader : public Grantlee::FileSystemTemplateLoader
 {
 public:
